@@ -8,7 +8,7 @@ from benchmark_runner.common.logger.logger_time_stamp import logger_time_stamp,
 from benchmark_runner.common.oc.oc_exceptions import PodNotCreateTimeout, PodNotInitializedTimeout, PodNotReadyTimeout, \
     PodNotCompletedTimeout, PodTerminateTimeout, PodNameNotExist, LoginFailed, VMNotCreateTimeout, VMTerminateTimeout, \
     YAMLNotExist, VMNameNotExist, VMNotInitializedTimeout, VMNotReadyTimeout, VMNotCompletedTimeout, \
-    OCPResourceNotCreateTimeout
+    OCPResourceNotCreateTimeout, KataInstallationFailed
 from benchmark_runner.common.ssh.ssh import SSH
 from benchmark_runner.main.environment_variables import environment_variables
 
@@ -54,6 +54,13 @@ class OC(SSH):
         """
         return self.run("oc get csv -n openshift-storage $(oc get csv -n openshift-storage --no-headers | awk '{ print $1; }') -ojsonpath='{.spec.version}' ")
 
+    def get_kata_version(self):
+        """
+        This method returns kata version
+        :return:
+        """
+        return self.run("oc get csv -n openshift-sandboxed-containers-operator $(oc get csv -n openshift-sandboxed-containers-operator --no-headers | awk '{ print $1; }') -ojsonpath='{.spec.version}' ")
+
     def is_cnv_installed(self):
         """
         This method check if cnv operator is installed
@@ -663,20 +670,13 @@ class OC(SSH):
                 self.wait_for_ocp_resource_create(resource='kata',
                                                   verify_cmd='oc -n openshift-sandboxed-containers-operator wait deployment/controller-manager --for=condition=Available',
                                                   status='deployment.apps/controller-manager condition met')
-            # for second script wait for refresh status
+            # for second script wait for kataconfig installation to no longer be in progress
             else:
-                # verify if there are workers nodes
-                if self.wait_for_ocp_resource_create(resource='ocs',
-                                                  verify_cmd="oc get mcp -n openshift-sandboxed-containers-operator $( oc get mcp -n openshift-sandboxed-containers-operator --no-headers | awk '{ print $1; }' | awk NR==2) -ojsonpath='{.status.machineCount}'",
-                                                  kata_worker_machine_count=True):
-                    # Wait till workers UPDATED==True
-                    self.wait_for_ocp_resource_create(resource='kata',
-                                                      verify_cmd="oc get mcp -n openshift-sandboxed-containers-operator $( oc get mcp -n openshift-sandboxed-containers-operator --no-headers | awk '{ print $1; }' | awk NR==2) -ojsonpath='{.status.conditions[3].status}'",
-                                                      status='True')
-                # There are only master nodes
-                else:
-                    # Wait till masters UPDATED==True
-                    self.wait_for_ocp_resource_create(resource='kata',
-                                                      verify_cmd="oc get mcp -n openshift-sandboxed-containers-operator $( oc get mcp -n openshift-sandboxed-containers-operator --no-headers | awk '{ print $1; }' | awk NR==1) -ojsonpath='{.status.conditions[3].status}'",
-                                                      status='True')
+                self.wait_for_ocp_resource_create(resource='kata',
+                                                  verify_cmd="oc get kataconfig -ojsonpath='{.items[0].status.installationStatus.IsInProgress}'",
+                                                  status='false')
+                totalNodesCount = self.run(cmd="oc get kataconfig -ojsonpath='{.items[0].status.totalNodesCount}'")
+                completedNodesCount = self.run(cmd="oc get kataconfig -ojsonpath='{.items[0].status.installationStatus.completed.completedNodesCount}'")
+                if totalNodesCount != completedNodesCount:
+                    raise KataInstallationFailed(f'not all nodes installed successfully total {totalNodesCount} != completed {completedNodesCount}')
         return True
